package com.ruoyi.app.mapper;

import java.util.List;

import com.ruoyi.app.DTO.PigpenDTO;
import com.ruoyi.app.model.Pigpen;

/**
 * 待宰圈Mapper接口
 * 
 * @author coede
 * @date 2025-03-19
 */
public interface PigpenMapper 
{
    /**
     * 查询待宰圈
     * 
     * @param id 待宰圈主键
     * @return 待宰圈
     */
    public Pigpen selectPigpenById(Long id);

    /**
     * 查询最近添加的待宰圈
     *
     * @return 待宰圈
     */
    public Pigpen selectLastPigpen();

    /**
     * 查询待宰圈列表
     * 
     * @param pigpen 待宰圈
     * @return 待宰圈集合
     */
    public List<PigpenDTO> printPigpenList(Pigpen pigpen);


    public List<Pigpen> selectPigpenList(Pigpen pigpen);

    /**
     * 校验待宰圈名称是否唯一
     *
     * @param pigpenName 待宰圈名称
     * @return 结果
     */
    public Pigpen checkPigpenNameUnique(String pigpenName);

    /**
     * 新增待宰圈
     * 
     * @param pigpen 待宰圈
     * @return 结果
     */
    public int insertPigpen(Pigpen pigpen);

    /**
     * 修改待宰圈
     * 
     * @param pigpen 待宰圈
     * @return 结果
     */
    public int updatePigpen(Pigpen pigpen);

    /**
     * 删除待宰圈
     * 
     * @param id 待宰圈主键
     * @return 结果
     */
    public int deletePigpenById(Long id);

    /**
     * 批量删除待宰圈
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deletePigpenByIds(Long[] ids);
}
